<?php

$wp_analytify = new WP_Analytify();

if (! function_exists( 'curl_init' ) ) {
	
	esc_html_e('This plugin requires the CURL PHP extension');
	return false;
}

if (! function_exists( 'json_decode' ) ) {
	
	esc_html_e('This plugin requires the JSON PHP extension');
	return false;
}

if (! function_exists( 'http_build_query' )) {
	
	esc_html_e('This plugin requires http_build_query()');
	return false;
}

$url = http_build_query( array(
							
							'next'            =>  $wp_analytify->pa_setting_url(),
							'scope'           =>  ANALYTIFY_SCOPE,
							'response_type'   =>  'code',
							'redirect_uri'    =>  ANALYTIFY_REDIRECT,
							'client_id'       =>  ANALYTIFY_CLIENTID,
							'access_type'     =>  'offline',
							'approval_prompt' =>  'auto'
						)
		);

// Save access code
if ( isset( $_POST[ 'save_code' ] ) ) {
	
	$key_google_token = $_POST[ 'key_google_token' ];

	if( $wp_analytify->pt_save_data( $key_google_token )){
		$update_message = '<div id="setting-error-settings_updated" class="updated settings-error below-h2"><p><strong>Access code saved.</strong></p></div>';
	}
}

// Saving settings for front end Analytics for Posts and Pages.

if ( isset( $_POST[ 'save_settings_front' ] ) ){

	if(isset($_POST[ 'posts_front' ]))
		update_option('analytify_posts_stats_front', $_POST[ "posts_front" ]);
	else
		update_option('analytify_posts_stats_front', false);

	if(isset($_POST[ 'frontend_stats' ])){

		update_option('post_analytics_settings_front', $_POST[ "frontend_stats" ]);
	}

	update_option( 'post_analytics_exclude_posts_front', @$_POST[ 'exclude_posts_front' ]);
	update_option( 'post_analytics_access', $_POST[ 'access_role' ]);
		
	if( isset( $_POST[ 'disable_front' ] ) ) {
			
		update_option( 'analytify_disable_front', 1 );
	}
	else{
			 
		update_option( 'analytify_disable_front', 0 );
	}

	$update_message = '<div id="setting-error-settings_updated" class="updated settings-error below-h2"><p><strong>Front-end changes are saved.</strong></p></div>';
	
} // endif

// Saving settings for back end Analytics for Posts and Pages.
if ( isset( $_POST[ 'save_settings_admin' ] ) ) {

	update_option( 'post_analytics_settings_back' , $_POST[ 'backend' ] );
	update_option( 'analytify_posts_stats' , $_POST[ 'posts' ] );
	update_option( 'post_analytics_access_back' , $_POST[ 'access_role_back' ] );
	update_option( 'post_analytics_disable_back' , @$_POST[ 'disable_back' ] );
	update_option( 'post_analytics_exclude_posts_back', @$_POST[ 'exclude_posts_back' ]);
		
	$update_message = '<div id="setting-error-settings_updated" class="updated settings-error below-h2"><p><strong>Admin changes are saved.</strong></p></div>';
	
} // endif

// Saving Profiles
if (isset($_POST[ 'save_profile' ])) {

	$profile_id            = $_POST[ 'webprofile' ];
	$display_tracking_code = $_POST[ 'display_tracking_code' ];
	$tracking_code         = $_POST[ 'tracking_code' ];
	$web_profile_dashboard = $_POST[ 'webprofile_dashboard' ];
	$web_profile_url       = $_POST[ $web_profile_dashboard ];
	$webPropertyId         = $_POST[ $profile_id."-1"];

	update_option( 'pt_webprofile', $profile_id );
	update_option( 'webPropertyId', $webPropertyId);
	update_option( 'pt_webprofile_dashboard', $web_profile_dashboard );
	update_option( 'pt_webprofile_url', urldecode( urldecode( $web_profile_url )));
	update_option( 'analytify_tracking_code', $tracking_code);
	update_option( 'display_tracking_code', $display_tracking_code);

	if( isset( $_POST[ 'ga_code' ] ) ) {
		update_option( 'analytify_code', 1 );
	}
	else{
		update_option( 'analytify_code', 0 );
	}
	
	$update_message = '<div id="setting-error-settings_updated" class="updated settings-error below-h2"> 
												<p><strong>Your Google Analytics Profile Saved.</strong></p></div>';
}

// Clear Authorization and other data
if (isset($_POST[ "clear" ])) {

	delete_option( 'pt_webprofile' );
	delete_option( 'pt_webprofile_dashboard' );
	delete_option( 'pt_webprofile_url' );
	delete_option( 'pa_google_token' );
	delete_option( 'pa_welcome_message' );
	delete_option( 'post_analytics_token' );
	$update_message = '<div id="setting-error-settings_updated" class="updated settings-error below-h2"> 
												<p><strong>Authentication Cleared login again.</strong></p></div>';
}
?>

<div class="wrap">
	<h2 class='opt-title'><span id='icon-options-general' class='analytics-options'><img src="<?php echo plugins_url('wp-analytify-pro/images/wp-analytics-logo.png');?>" alt=""></span>
		<?php echo __( 'Analytify Plugin Settings', 'wp-analytify'); ?>
	</h2>
	
	<?php
	if (isset($update_message)) echo $update_message;
	
	if ( isset ( $_GET['tab'] ) ) $wp_analytify->pa_settings_tabs($_GET['tab']); 
	else $wp_analytify->pa_settings_tabs( 'authentication' );

	if ( isset ( $_GET['tab'] ) ) 
		$tab = $_GET['tab']; 
	else 
		$tab = 'authentication';
	
	// Authentication Tab section
	if( $tab == 'authentication' ) {
	?>

	<form action="<?php echo str_replace( '%7E', '~', $_SERVER['REQUEST_URI']); ?>" method="post" name="settings_form" id="settings_form">
		<table width="1004" class="form-table">
			<tbody>
			<?php if( get_option( 'pa_google_token' ) ) { ?>
				<tr>
					<p class="description"><br />Do you want to re-authenticate ? Click reset button and get your new Access code.<p>
					
				</tr>
				<tr>
					<th><?php esc_html_e( 'Clear Authentication', 'wp-analytify' ); ?></th>
					<td><input type="submit" class="button-primary" value="Reset" name="clear" /></td>
				</tr>
			<?php 
			}
			else { ?>
				<tr>
					<th width="115"><?php esc_html_e( 'Authentication:' )?></th>
						<td width="877">
							<a target="_blank" href="javascript:void(0);" onclick="window.open('https://accounts.google.com/o/oauth2/auth?<?php echo $url ?>','activate','width=700,height=500,toolbar=0,menubar=0,location=0,status=1,scrollbars=1,resizable=1,left=0,top=0');">Click here to Authenticate</a>
						</td>
				</tr>
				<tr>
					<th><?php esc_html_e('Your Access Code:')?> </th>
						<td>
							<input type="text" name="key_google_token" value="" style="width:450px;"/>
							<p class="description">Paste here Access Code. <a href="https://www.screenr.com/UmmN" target="_blank"> click here</a> to watch installation and configuration video.</p>
						</td>
				</tr>
				<tr>
					<th></th>
					<td>
						<p class="submit">
							<input type="submit" class="button-primary" value="Save Changes" name="save_code" />
						</p>
					</td>
				</tr>
			<?php } ?>
			</tbody>
		</table>
	</form>
	<?php
	} // endif
// Choose profiles for dashboard and posts at front/back.
if( $tab == 'profile' ){

	$profiles = $wp_analytify->pt_get_analytics_accounts();
	
	if( isset( $profiles ) ) { ?>
		<p class="description"><br /><?php esc_html_e( 'Select your profiles for front-end and backend sections.', 'wp-analytify' ); ?></p>

		<form action="<?php echo str_replace( '%7E', '~', $_SERVER['REQUEST_URI']); ?>" method="post">
			<table width="1004" class="form-table">
				<tbody>
				<tr>
						<th width="115"><?php esc_html_e( 'Install Google Analytics tracking code :', 'wp-analytify' ); ?></th>
							<td width="877">
							<input type="checkbox" name="ga_code" value="1" 
									<?php if( get_option( 'analytify_code' ) == 1 ) { echo 'checked'; } ?>>
									<p class="description">Insert Google Analytics JS code in header to track the visitors. You can uncheck this option if you have already insert the GA code in your website.</p>
							</td>
				</tr>
				<tr>
				<th width="115">
						<?php esc_html_e( 'Exclude users from tracking :', 'wp-analytify' ); ?>
				</th>
				<td>
					<select multiple name="display_tracking_code[]" class="analytify-chosen" style="width:306px">
							<?php
							
							if ( !isset( $wp_roles ) ) {
								
								$wp_roles = new WP_Roles();
							}
							
							foreach ( $wp_roles->role_names as $role => $name ) { ?>
								
								<option value="<?php echo $role; ?>"
								<?php
								
								if ( is_array( get_option( 'display_tracking_code' ) ) ) {
									
									selected( in_array( $role, get_option('display_tracking_code') ) );
								
								}
								
								?>>
										<?php echo $name; ?>
								</option>
							<?php 
								} 
							?>
					</select>
					<p class="description">Don't insert the tracking code for above user roles.</p>
				</td>
			</tr>
				<tr>
						<th width="115"><?php esc_html_e( 'Tracking code type :', 'wp-analytify' ); ?></th>
							<td width="877">
							<select name='tracking_code' class="analytify-chosen">
								<option value="universal" <?php selected( 'universal', get_option( 'analytify_tracking_code' ) ); ?>>
									Universal Code (analytics.js)
								</option>
								<option value="ga"  <?php selected( 'ga', get_option( 'analytify_tracking_code' ) ); ?>>
									Tranditional Code (ga.js)
								</option>
								 
							</select>
							<p class="description">Which type of tracking code to use i-e (Analytics.js , ga.js) Google recommends to use Analytics.js now <a href="https://developers.google.com/analytics/devguides/collection/upgrade/reference/gajs-analyticsjs" target="_blank">Read More</a>.</p>
							</td>
				</tr>
					<tr>
						<th width="115"><?php esc_html_e( 'Profile for posts (Backend/Front-end) :', 'wp-analytify' ); ?></th>
							<td width="877">
							<?php //print_r($profiles->items); ?>
								<select name='webprofile' class="analytify-chosen">
									<?php foreach ( $profiles->items as $profile ) { ?>
												<option value="<?php echo $profile[ 'id' ];?>"
																<?php selected( $profile[ 'id' ], get_option( 'pt_webprofile' ) ); ?>>
																<?php echo $profile[ 'websiteUrl' ];?> - <?php echo $profile[ 'name' ];?>
												</option>
									<?php } ?>
								</select>
								 <?php 
								foreach ( $profiles->items as $profile ) { ?>
									<input type="hidden" name="<?php echo $profile[ 'id' ]; ?>-1" value="<?php echo $profile['webPropertyId'] ?>">
								<?php } ?>
								 <p class="description">Select your website profile for wp-admin edit pages and fron-end pages. Select profile which matches your current WordPress website.</p>
							</td>

					</tr>
					<tr>
						<th width="115"><?php esc_html_e( 'Profile for Dashboard :', 'wp-analytify' );?></th>
						<td width="877">
								<select name='webprofile_dashboard' class="analytify-chosen">
									<?php foreach ($profiles->items as $profile) { ?>
									<option value="<?php echo $profile[ 'id' ];?>"
										<?php selected( $profile[ 'id' ], get_option( 'pt_webprofile_dashboard' )); ?>
										>
										<?php echo $profile[ 'websiteUrl' ];?> - <?php echo $profile[ 'name' ];?>
									</option>
									<?php } ?>
								</select>
								<?php 
								foreach ( $profiles->items as $profile ) { ?>
									<input type="hidden" name="<?php echo $profile[ 'id' ]; ?>" value="<?php echo urlencode(urlencode($profile[ 'websiteUrl' ])); ?>">
								<?php } ?>
								<p class="description">Select your website profile for Dashboard Stats. You can select your any Website profile. It will show Analytics for your selected website profile.</p>
						</td>
					</tr>
					<tr>
						<th></th>
						<td>
							<p class="submit">
								<input type="submit" name="save_profile" value="Save Changes" class="button-primary">
							</p>
						</td>
					</tr>
					<?php } ?>
			</tbody>
		</table>
	</form>
<?php }

// Choose metrics for posts at front.
if( $tab == 'front' ) { ?>

	<p class="description"><br /><?php esc_html_e( 'Following are the settings for front-end side. Google Analytics will appear under the posts, custom post types or pages at front-end.', 'wp-analytify' ); ?></p>

	<form action="" method="post">
		<table width="1004" class="form-table">
			<tbody>
			<tr>
				<th width="115"><?php esc_html_e( 'Disable front-end :', 'wp-analytify' ); ?></th>
				<td>
					<input type="checkbox" name="disable_front" id="disable_front" value = "1"
						<?php if( get_option( 'analytify_disable_front') == 1 ) { echo 'checked'; } ?>>
						<p class="description">Check it, if you don't want to load Analytics at all. Remember, you can use Shortcodes still.</p>
				</td>
			</tr>
			<tr>
				<th width="115">
					<div class="disable">
						<?php esc_html_e( 'Show Analytics to (roles) :', 'wp-analytify' ); ?>
					</div>
				</th>
				<td>
						<div class="disable" >  
						<select multiple name="access_role[]" class="analytify-chosen" style="width:306px">
								<option value="every-one" 
										<?php
											if ( is_array( get_option( 'post_analytics_access' ) ) ) {
												selected( in_array( 'every-one', get_option('post_analytics_access') ) );
											}
											?>>
									Every One 
								</option>
								<?php
								
								if ( !isset( $wp_roles ) ) {
										$wp_roles = new WP_Roles();
								}

								$i = 0;
							
								foreach ( $wp_roles->role_names as $role => $name ) { ?>
										<option value="<?php echo $role; ?>"
												<?php
												if ( is_array( get_option( 'post_analytics_access' ) ) ) {
														selected( in_array( $role, get_option('post_analytics_access') ) );
												}
												?>>
												<?php echo $name; ?>
										</option>
								<?php
								} // end foreach
								?>
						</select>
					</div>
					</div> 
					<p class="description">Show Analytics to above selected user roles only.</p>  
				</td>
			</tr>
			<tr>
						<!-- Area For front-end settings -->
						<th width="115"><div class="disable" > 
							<?php esc_html_e( 'Analytics on Post types :' ,'wp-analytify'); ?> </div>
						</th>
						<td>
								<div class="disable" >
							 <select class="analytify-chosen" name="posts_front[]" multiple="multiple" style="width:400px">
										<?php
											$args = array(
																		 'public'   => true,
																		 
																		); 
												$post_types = get_post_types( $args );
													 foreach ( $post_types as $post_type ) {
										?>
										<option value="<?php echo $post_type ?>" 
												<?php if ( is_array( get_option( 'analytify_posts_stats_front' ) ) ) {
																selected(in_array($post_type, get_option('analytify_posts_stats_front')));
															}  ?>>
												<?php echo $post_type; ?>
										</option>
										<?php } ?>
							 </select>
							</div>
							<p class="description">Show Analytics under the above post types only.</p>  
						</td>
						</tr>
					<tr> 
			<tr>
						<!-- Area For frontend settings -->
						<th width="115"><div class="disable" > <?php esc_html_e( 'Front-end Analytics panels:' ); ?></div></th>
						<td>
							<div class="disable" > 
									<select class="analytify-chosen" name="frontend_stats[]" multiple style="width:306px">
										<option value="show-overall-front"
														<?php
														if ( is_array( get_option( 'post_analytics_settings_front' ) ) ) {
															selected(in_array("show-overall-front", get_option('post_analytics_settings_front')));
														}
														?>>
														<?php esc_html_e( 'General Stats' )?>
										</option>
										<option value="show-country-front"
														<?php
														if ( is_array( get_option( 'post_analytics_settings_front' ) ) ) {
															selected( in_array( "show-country-front", get_option( 'post_analytics_settings_front' ) ) );
														}
														?>>
														<?php esc_html_e( 'Country Stats' )?>
										</option>
										<option value="show-keywords-front"
														<?php
														if ( is_array ( get_option( 'post_analytics_settings_front' ) ) ) {
															selected( in_array( "show-keywords-front", get_option( 'post_analytics_settings_front' ) ) );
														}
														?>>
														<?php esc_html_e( 'Keywords Stats' ); ?>
										</option>
										<option value="show-social-front"
														<?php
														if ( is_array ( get_option( 'post_analytics_settings_front' ) ) ) {
															selected( in_array( "show-social-front", get_option( 'post_analytics_settings_front' ) ) );
														}
														?>>
														<?php esc_html_e( 'Social Media Stats' ); ?>
										</option>
										<option value="show-browser-front"
														<?php
														if ( is_array( get_option( 'post_analytics_settings_front' ) ) ) {
															selected( in_array( "show-browser-front", get_option( 'post_analytics_settings_front') ) );
														}
														?>>
														<?php esc_html_e( 'Browser Stats' ); ?>
										</option>
										<option value="show-referrer-front"
														<?php
														if ( is_array( get_option( 'post_analytics_settings_front' ) ) ) {
															selected( in_array( "show-referrer-front", get_option( 'post_analytics_settings_front') ) );
														}
														?>>
														<?php esc_html_e( 'Referrers' ); ?>
										</option>
									 
										<option value="show-mobile-front"
														<?php
														if ( is_array ( get_option( 'post_analytics_settings_front' ) ) ) {
															selected( in_array( "show-mobile-front", get_option( 'post_analytics_settings_front' ) ) );
														}
														?>>
														<?php esc_html_e( 'Mobile devices Stats' ); ?>
										</option>
										<option value="show-os-front"
														<?php
														if ( is_array ( get_option( 'post_analytics_settings_front' ) ) ) {
															selected( in_array( "show-os-front", get_option( 'post_analytics_settings_front' ) ) );
														}
														?>>
														<?php esc_html_e( 'Operating System Stats' ); ?>
										</option>
										<option value="show-city-front"
														<?php
														if ( is_array ( get_option( 'post_analytics_settings_front' ) ) ) {
															selected( in_array( "show-city-front", get_option( 'post_analytics_settings_front' ) ) );
														}
														?>>
														<?php esc_html_e( 'City Stats' ); ?>
										</option>
									</select>
							</div>
							<p class="description">Select which Stats panels you want to display at front-end.</p>  
						</td>
					</tr>
					<tr>
						 <th width="115"><div class="disable" ><?php esc_html_e( 'Exclude Analytics on specific pages:', 'wp-analytify' ); ?></div></th>
						<td>
							<div class="disable">
								<input type="text" name="exclude_posts_front" id="exclude_posts_front" class="regular-text" value="<?php echo get_option('post_analytics_exclude_posts_front'); ?>" />
							</div>
							<p class="description">Enter ID's of posts or pages separated by commas on which you don't want to show Analytics e.g 11,45,66</p>  
						</td>
					</tr>
			<tr>
				<th></th>
				<td>
					<p class="submit"> <input type="submit" name="save_settings_front" value="Save Changes" class="button-primary"></p>
				</td>
			</tr>
		</tbody>
	</table>
	</form>
	<?php }
	
	// Choose metrics for posts at admin.
	if( $tab == 'admin' ) { ?>

		<p class="description"><br /><?php esc_html_e( 'Following are the settings for Admin side. Google Analytics will appear under the posts, custom post types or pages.', 'wp-analytify' ); ?></p>

		<form action="" method="post">
			<table width="1004" class="form-table">
				<tbody>
					<tr></tr>
					<tr>
						<th><?php _e( 'Disable Analytics under posts/pages (wp-admin):', 'wp-analytify') ?></th>
						<td>
								<input type="checkbox" name="disable_back" value="1" <?php if ( get_option( 'post_analytics_disable_back') == 1 ) { ?> checked <?php } ?>>
								<p class="description">Check it, If you don't want to load Stats by default on all pages. Remember, There is a section under each post/page. You can still view Stats on pages you want.</p>
						</td>
						
					</tr>
					<tr>
						<th width="115"><?php esc_html_e( 'Show Analytics to (roles) :', 'wp-analytify' ); ?></th>
						<td>
							<select multiple name="access_role_back[]" class="analytify-chosen" style="width:400px">
								<?php
								if ( !isset( $wp_roles ) ){
									
									$wp_roles = new WP_Roles();
								}
								
								$i=0;
								foreach ( $wp_roles->role_names as $role => $name ) {
									
									if ($role!='subscriber'){
										
										$i++;
										
										?>
										<option value="<?php echo $role; ?>"
											<?php
											
											if ( is_array( get_option( 'post_analytics_access_back' ) ) ) {
												selected( in_array( $role, get_option( 'post_analytics_access_back' ) ) );
											}
											?>>
											<?php echo $name; ?>
										</option>
										<?php
									}
								}
								?>
							</select>
							<p class="description">Show Analytics to above selected user roles only.</p>
						</td>
					</tr>
					<tr>
						<!-- Area For backend settings -->
						<th width="115"><?php esc_html_e( 'Analytics on Post types :' ,'wp-analytify'); ?></th>
						<td>
							 <select class="analytify-chosen" name="posts[]" multiple="multiple" style="width:400px">
										<?php
											$args = array(
																		 'public'   => true,
																		 
																		); 
												$post_types = get_post_types( $args );
													 foreach ( $post_types as $post_type ) {
										?>
										<option value="<?php echo $post_type ?>" 
												<?php if ( is_array( get_option( 'analytify_posts_stats' ) ) ) {
																selected(in_array($post_type, get_option('analytify_posts_stats')));
															}  ?>>
												<?php echo $post_type; ?>
										</option>
										<?php } ?>
							 </select>
							 <p class="description">Show Analytics under the above post types only.</p>
						</td>
						</tr>
					<tr>
						<!-- Area For backend settings -->
						<th width="115"><?php esc_html_e( 'Edit pages/posts Analytics panels:' ); ?></th>
						<td>
							<select class="analytify-chosen" name="backend[]" multiple="multiple" style="width:400px">
								<option value="show-overall-back"
												<?php
												if ( is_array( get_option( 'post_analytics_settings_back' ) ) ) {
													selected(in_array("show-overall-back", get_option('post_analytics_settings_back')));
												}
												?>>
												<?php esc_html_e( 'General Stats' )?>
								</option>
								<option value="show-country-back"
												<?php
												if ( is_array( get_option( 'post_analytics_settings_back' ) ) ) {
													selected( in_array( "show-country-back", get_option( 'post_analytics_settings_back' ) ) );
												}
												?>>
												<?php esc_html_e( 'Country Stats' )?>
								</option>
								
								<option value="show-keywords-back"
												<?php
												if ( is_array ( get_option( 'post_analytics_settings_back' ) ) ) {
													selected( in_array( "show-keywords-back", get_option( 'post_analytics_settings_back' ) ) );
												}
												?>>
												<?php esc_html_e( 'Keywords Stats' ); ?>
								</option>
								<option value="show-social-back"
												<?php
												if ( is_array ( get_option( 'post_analytics_settings_back' ) ) ) {
													selected( in_array( "show-social-back", get_option( 'post_analytics_settings_back' ) ) );
												}
												?>>
												<?php esc_html_e( 'Social Media Stats' ); ?>
								</option>
								<option value="show-browser-back"
												<?php
												if ( is_array( get_option( 'post_analytics_settings_back' ) ) ) {
													selected( in_array( "show-browser-back", get_option( 'post_analytics_settings_back') ) );
												}
												?>>
												<?php esc_html_e( 'Browser Stats' ); ?>
								</option>
								<option value="show-referrer-back"
												<?php
												if ( is_array( get_option( 'post_analytics_settings_back' ) ) ) {
													selected( in_array( "show-referrer-back", get_option( 'post_analytics_settings_back') ) );
												}
												?>>
												<?php esc_html_e( 'Referrers' ); ?>
								</option>
								<option value="show-pages-back"
												<?php
												if ( is_array( get_option( 'post_analytics_settings_back' ) ) ) {
													selected( in_array( "show-pages-back", get_option( 'post_analytics_settings_back' ) ) );
												}
												?>>
												<?php esc_html_e(' Page bounce and exit stats '); ?>
								</option>
								<option value="show-mobile-back"
												<?php
												if ( is_array ( get_option( 'post_analytics_settings_back' ) ) ) {
													selected( in_array( "show-mobile-back", get_option( 'post_analytics_settings_back' ) ) );
												}
												?>>
												<?php esc_html_e( 'Mobile Devices Stats' ); ?>
								</option>
								<option value="show-os-back"
												<?php
												if ( is_array ( get_option( 'post_analytics_settings_back' ) ) ) {
													selected( in_array( "show-os-back", get_option( 'post_analytics_settings_back' ) ) );
												}
												?>>
												<?php esc_html_e( 'Operating System Stats' ); ?>
								</option>
								<option value="show-city-back"
												<?php
												if ( is_array ( get_option( 'post_analytics_settings_back' ) ) ) {
													selected( in_array( "show-city-back", get_option( 'post_analytics_settings_back' ) ) );
												}
												?>>
												<?php esc_html_e( 'City Stats' ); ?>
								</option>
							</select>
							<p class="description">Select which Stats panels you want to display under posts/pages.</p>
						</td>
					</tr>
					 <tr>
						 <th width="115"><?php esc_html_e( 'Exclude Analytics on specific pages:', 'wp-analytify' ); ?></th>
							<td>
								<input type="text" name="exclude_posts_back" id="exclude_posts_back" value="<?php echo get_option('post_analytics_exclude_posts_back'); ?>" class="regular-text" />
							<p class="description">Enter ID's of posts or pages separated by commas on which you don't want to show Analytics e.g 11,45,66</p>
						</td>
					</tr>
					<tr>
						<th></th>
						<td>
							<p class="submit">
								<input type="submit" name="save_settings_admin" value="Save Changes" class="button-primary">
							</p>
						</td>
					</tr>
				</tbody>
			</table>
		</form>
	<?php 
	}
	// Plugin license Tab section
	if( $tab == 'license' ) {

			$license  = get_option( 'analytify_license_key' );
			$status   = get_option( 'analytify_license_status' );

		?>
		<div class="wrap">
			<form method="post" action="options.php">
		
			<?php settings_fields('analytify-settings'); ?>
			
			<table class="form-table">
				<tbody>
					<tr valign="top"> 
						<th scope="row" valign="top">
							<?php _e('License Key:', 'wp-analytify'); ?>
						</th>
						<td>
							<input id="analytify_license_key" name="analytify_license_key" type="text" class="regular-text" value="<?php esc_attr_e( $license ); ?>" />
							<p class="description" for="analytify_license_key"><?php _e('Enter your license key. It is important to have a valide license for automatic plugin updates and support. After adding license key, press \'Save Changes\' and then press "Activate" button.'); ?></p>
						</td>
					</tr>

					<?php do_action('edd_license_key'); ?>
					<?php do_action('woocommerce_license_key'); ?>

					<?php if( !empty( $license ) ) { ?>
						<tr valign="top"> 
							<th scope="row" valign="top">
								<?php _e('Activate License'); ?>
							</th>
							<td>
								<?php if( $status !== false && $status == 'valid' ) { ?>
									<span style="color:green;"><?php _e('Active'); ?></span>
									<?php wp_nonce_field( 'analytify_nonce', 'analytify_nonce' ); ?>
									<input type="submit" class="button-secondary" name="analytify_license_deactivate" value="<?php _e('Deactivate License'); ?>"/>
								<?php } else {
									wp_nonce_field( 'analytify_nonce', 'analytify_nonce' ); ?>
									<span style="color:red;"><?php _e( $status ); ?></span>
									<input type="submit" class="button-secondary" name="analytify_license_activate" value="<?php _e('Activate License'); ?>"/>
								<?php } ?>
							</td>
						</tr>
					<?php } ?>
				</tbody>
			</table>  
			<?php submit_button(); ?>
		
		</form>
	<?php } ?>

</div>
</div>
<div class="right-area">
	<div class="postbox-container side">
		<script type="text/javascript" src="http://wpbrigade.com/updates/syndicate-analytify-new.php"></script>
				<div class="metabox-holder">
					<div class="grids_auto_size wpa_side_box" style="width: 95%;">
						<div class="grid_title cen"> HELP </div>
								
								<div class="grid_footer cen" style="background-color:white;">
								<a href="http://wpbrigade.com/forums/forum/analytify-makes-google-analytics-simple-for-wordpress/" title="Analytify Support">Click here</a> to get the support of Analytify. You can submit bug reports and give us suggestions as well.
								</div>
					</div>
					<div class="grids_auto_size wpa_side_box" style=" width: 95%;">
						<div class="grid_title cen"> CREDITS </div>
								
								<div class="grid_footer cen" style="background-color:white;">
									<a href="http://wp-analytify.com" title="Analytify WordPress Plugin" />Analytify - Makes Google Analytics Simple for WordPress.</a><br><br>
									Product by <a href="http://wpbrigade.com" title="WPBrigade | A Brigade of WordPress Developers." />WPBrigade</a>.
								</div>
					</div>
			 </div>
	</div>
</div>